pub struct PublishRecord {
pub marketplace_id: String,
pub locale: String,
pub asin: String,
pub content_type: ContentType,
pub content_sub_type: Option<String>,
pub content_reference_key: String,
}Expand description
PublishRecord : The full context for an A+ Content publishing event.
Fields
marketplace_id: StringThe identifier for the marketplace where the A+ Content is published.
locale: StringThe IETF language tag. This only supports the primary language subtag with one secondary language subtag. The secondary language subtag is almost always a regional designation. This does not support additional subtags beyond the primary and secondary subtags. Pattern: ^[a-z]{2,}-[A-Z0-9]{2,}$
asin: StringThe Amazon Standard Identification Number (ASIN).
content_type: ContentTypecontent_sub_type: Option<String>The A+ Content document subtype. This represents a special-purpose type of an A+ Content document. Not every A+ Content document type will have a subtype, and subtypes may change at any time.
content_reference_key: StringA unique reference key for the A+ Content document. A content reference key cannot form a permalink and may change in the future. A content reference key is not guaranteed to match any A+ content identifier.
Implementations
sourceimpl PublishRecord
impl PublishRecord
sourcepub fn new(
marketplace_id: String,
locale: String,
asin: String,
content_type: ContentType,
content_reference_key: String
) -> PublishRecord
pub fn new(
marketplace_id: String,
locale: String,
asin: String,
content_type: ContentType,
content_reference_key: String
) -> PublishRecord
The full context for an A+ Content publishing event.